@@ -44,7 +44,7 @@ class LaunchError(Exception):
     def __init__(self, error_msg):
         super(LaunchError, self).__init__()
 
-        self.error_msg = textwrap.shorten(error_msg, width=256)
+        self.error_msg = error_msg
 
 
 @XBlock.wants('settings')
@@ -559,6 +559,10 @@ class HastexoXBlock(XBlock,
         frag.add_javascript_url(
             self.runtime.local_resource_url(self, 'public/js/main.js')
         )
+        frag.add_javascript_url(
+            self.runtime.local_resource_url(
+                self, 'public/js/guacamole-common-js/all.min.js')
+        )
 
         # Create the stack in the database
         stack = self.create_stack(settings, course_id, student_id)
@@ -571,9 +575,6 @@ class HastexoXBlock(XBlock,
             "protocol": self.stack_protocol,
             "ports": self.ports,
             "port": stack.port,
-            "color_scheme": settings.get("terminal_color_scheme"),
-            "font_name": settings.get("terminal_font_name"),
-            "font_size": settings.get("terminal_font_size"),
             "instructions_layout": settings.get("instructions_layout"),
             "read_only": self.read_only,
             "progress_check_label": self.progress_check_label,
@@ -854,10 +855,7 @@ class HastexoXBlock(XBlock,
         return {
             "status": stack.status,
             "error_msg": stack.error_msg,
-            "ip": stack.ip,
-            "user": stack.user,
-            "key": stack.key,
-            "password": stack.password
+            "name": stack.name
         }
 
     @XBlock.json_handler
